/*
File: CommandMessage.java
Date		Author		Changes
Aug 22 96	Lukasz Beca	Created
*/

package webwisdom.tango.messages;

import webwisdom.tango.messages.Message;
import webwisdom.tango.consts.Const;
import java.io.*;


/**
 * A class representing message COMMAND
 * 
 *@author Lukasz Beca
 *@see Central Server - Local Demon protocol
 **/


public class CommandMessage extends Message {
  
  private int AT;
  private String PARAM;
  private int AID;
  private int SID;

  /**
   * Creates a new COMMAND message
   *@param ATparam  application type
   *@param PARAMparam  parameters for application
   *@param AIDparam application number
   *@param SIDparam  session number
   **/


  public CommandMessage(int ATparam, String PARAMparam, int AIDparam, int SIDparam) {

   AT = ATparam;
   SID = SIDparam;
   PARAM = new String(PARAMparam);
   AID = AIDparam;
   type = Const.COMMAND;
  }


  /**
   * Creates a new COMMAND message, information is read from the input stream
   *@param instream  input stream
   *@exception IOException
   **/

  CommandMessage(DataInputStream instream) throws IOException {
    

    AT = instream.readInt();
    PARAM = instream.readUTF();
    AID = instream.readInt();
    SID = instream.readInt();

    type = Const.COMMAND;
    
  }

  /**
   * Writes COMMAND message to the output stream
   *@param outstream  output stream
   **/


  void send(DataOutputStream outstream) throws IOException {
  

 
   // System.out.println("Sending type " + Const.COMMAND);
    outstream.writeInt(Const.COMMAND);
   // System.out.println("Sending AT " + AT);
    outstream.writeInt(AT);
   // System.out.println("Sending PARAM " + PARAM);
    outstream.writeUTF(PARAM);
   // System.out.println("Sending AID " + AID);
    outstream.writeInt(AID);
   // System.out.println("Sending SID " + SID);
    outstream.writeInt(SID);
    outstream.flush();
  

  }
  

  /**
   * Returns application type
   **/
  
  public int getAT() {
       
    return AT;

  }  

  /**
  * Returns session number 
  **/

  public int getSID() {
   
    return SID;
  }

  /**
  * Returns parameters 
  **/
  

  public String getPARAM() {
   
    String result;
    
    result =  new String(PARAM);

    return result;
  }

  /**
   * Returns application number
   **/


  public int getAID() {
   
    return AID;
  }
  
}


